# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/hyp.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/hyp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&protos/perfetto/trace/ftrace/hyp.proto\x12\x0fperfetto.protos\"\x15\n\x13HypEnterFtraceEvent\"\x14\n\x12HypExitFtraceEvent\"3\n\x14HostHcallFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0f\n\x07invalid\x18\x02 \x01(\r\"3\n\x12HostSmcFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x11\n\tforwarded\x18\x02 \x01(\r\"4\n\x17HostMemAbortFtraceEvent\x12\x0b\n\x03\x65sr\x18\x01 \x01(\x04\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.hyp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HYPENTERFTRACEEVENT']._serialized_start=59
  _globals['_HYPENTERFTRACEEVENT']._serialized_end=80
  _globals['_HYPEXITFTRACEEVENT']._serialized_start=82
  _globals['_HYPEXITFTRACEEVENT']._serialized_end=102
  _globals['_HOSTHCALLFTRACEEVENT']._serialized_start=104
  _globals['_HOSTHCALLFTRACEEVENT']._serialized_end=155
  _globals['_HOSTSMCFTRACEEVENT']._serialized_start=157
  _globals['_HOSTSMCFTRACEEVENT']._serialized_end=208
  _globals['_HOSTMEMABORTFTRACEEVENT']._serialized_start=210
  _globals['_HOSTMEMABORTFTRACEEVENT']._serialized_end=262
# @@protoc_insertion_point(module_scope)
