# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/trace_packet_defaults.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/trace_packet_defaults.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace.chrome import v8_pb2 as protos_dot_perfetto_dot_trace_dot_chrome_dot_v8__pb2
from protos.perfetto.trace.profiling import profile_packet_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_profile__packet__pb2
from protos.perfetto.trace.track_event import track_event_pb2 as protos_dot_perfetto_dot_trace_dot_track__event_dot_track__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1protos/perfetto/trace/trace_packet_defaults.proto\x12\x0fperfetto.protos\x1a%protos/perfetto/trace/chrome/v8.proto\x1a\x34protos/perfetto/trace/profiling/profile_packet.proto\x1a\x33protos/perfetto/trace/track_event/track_event.proto\"\xf2\x01\n\x13TracePacketDefaults\x12\x1a\n\x12timestamp_clock_id\x18: \x01(\r\x12\x41\n\x14track_event_defaults\x18\x0b \x01(\x0b\x32#.perfetto.protos.TrackEventDefaults\x12\x41\n\x14perf_sample_defaults\x18\x0c \x01(\x0b\x32#.perfetto.protos.PerfSampleDefaults\x12\x39\n\x10v8_code_defaults\x18\x63 \x01(\x0b\x32\x1f.perfetto.protos.V8CodeDefaults')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.trace_packet_defaults_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRACEPACKETDEFAULTS']._serialized_start=217
  _globals['_TRACEPACKETDEFAULTS']._serialized_end=459
# @@protoc_insertion_point(module_scope)
