# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: FlightSql.proto
# Protobuf Python Version: 5.29.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    1,
    '',
    'FlightSql.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x46lightSql.proto\x12\x19\x61rrow.flight.protocol.sql\x1a google/protobuf/descriptor.proto\"!\n\x11\x43ommandGetSqlInfo\x12\x0c\n\x04info\x18\x01 \x03(\r\">\n\x16\x43ommandGetXdbcTypeInfo\x12\x16\n\tdata_type\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x0c\n\n_data_type\"\x14\n\x12\x43ommandGetCatalogs\"{\n\x13\x43ommandGetDbSchemas\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12%\n\x18\x64\x62_schema_filter_pattern\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_catalogB\x1b\n\x19_db_schema_filter_pattern\"\xeb\x01\n\x10\x43ommandGetTables\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12%\n\x18\x64\x62_schema_filter_pattern\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x19table_name_filter_pattern\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x0btable_types\x18\x04 \x03(\t\x12\x16\n\x0einclude_schema\x18\x05 \x01(\x08\x42\n\n\x08_catalogB\x1b\n\x19_db_schema_filter_patternB\x1c\n\x1a_table_name_filter_pattern\"\x16\n\x14\x43ommandGetTableTypes\"n\n\x15\x43ommandGetPrimaryKeys\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdb_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05table\x18\x03 \x01(\tB\n\n\x08_catalogB\x0c\n\n_db_schema\"o\n\x16\x43ommandGetExportedKeys\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdb_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05table\x18\x03 \x01(\tB\n\n\x08_catalogB\x0c\n\n_db_schema\"o\n\x16\x43ommandGetImportedKeys\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdb_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05table\x18\x03 \x01(\tB\n\n\x08_catalogB\x0c\n\n_db_schema\"\xe6\x01\n\x18\x43ommandGetCrossReference\x12\x17\n\npk_catalog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cpk_db_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x08pk_table\x18\x03 \x01(\t\x12\x17\n\nfk_catalog\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x66k_db_schema\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x10\n\x08\x66k_table\x18\x06 \x01(\tB\r\n\x0b_pk_catalogB\x0f\n\r_pk_db_schemaB\r\n\x0b_fk_catalogB\x0f\n\r_fk_db_schema\"e\n$ActionCreatePreparedStatementRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\".\n\rSubstraitPlan\x12\x0c\n\x04plan\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x92\x01\n(ActionCreatePreparedSubstraitPlanRequest\x12\x36\n\x04plan\x18\x01 \x01(\x0b\x32(.arrow.flight.protocol.sql.SubstraitPlan\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"z\n#ActionCreatePreparedStatementResult\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\x12\x16\n\x0e\x64\x61taset_schema\x18\x02 \x01(\x0c\x12\x18\n\x10parameter_schema\x18\x03 \x01(\x0c\"H\n#ActionClosePreparedStatementRequest\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\"\x1f\n\x1d\x41\x63tionBeginTransactionRequest\"C\n\x1b\x41\x63tionBeginSavepointRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\"6\n\x1c\x41\x63tionBeginTransactionResult\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x0c\"2\n\x1a\x41\x63tionBeginSavepointResult\x12\x14\n\x0csavepoint_id\x18\x01 \x01(\x0c\"\xf9\x01\n\x1b\x41\x63tionEndTransactionRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x0c\x12U\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x45.arrow.flight.protocol.sql.ActionEndTransactionRequest.EndTransaction\"k\n\x0e\x45ndTransaction\x12\x1f\n\x1b\x45ND_TRANSACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45ND_TRANSACTION_COMMIT\x10\x01\x12\x1c\n\x18\x45ND_TRANSACTION_ROLLBACK\x10\x02\"\xea\x01\n\x19\x41\x63tionEndSavepointRequest\x12\x14\n\x0csavepoint_id\x18\x01 \x01(\x0c\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x41.arrow.flight.protocol.sql.ActionEndSavepointRequest.EndSavepoint\"d\n\x0c\x45ndSavepoint\x12\x1d\n\x19\x45ND_SAVEPOINT_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45ND_SAVEPOINT_RELEASE\x10\x01\x12\x1a\n\x16\x45ND_SAVEPOINT_ROLLBACK\x10\x02\"V\n\x15\x43ommandStatementQuery\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"\x87\x01\n\x1d\x43ommandStatementSubstraitPlan\x12\x36\n\x04plan\x18\x01 \x01(\x0b\x32(.arrow.flight.protocol.sql.SubstraitPlan\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"0\n\x14TicketStatementQuery\x12\x18\n\x10statement_handle\x18\x01 \x01(\x0c\"B\n\x1d\x43ommandPreparedStatementQuery\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\"W\n\x16\x43ommandStatementUpdate\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"C\n\x1e\x43ommandPreparedStatementUpdate\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\"\xb6\x07\n\x16\x43ommandStatementIngest\x12j\n\x18table_definition_options\x18\x01 \x01(\x0b\x32H.arrow.flight.protocol.sql.CommandStatementIngest.TableDefinitionOptions\x12\r\n\x05table\x18\x02 \x01(\t\x12\x13\n\x06schema\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x63\x61talog\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x11\n\ttemporary\x18\x05 \x01(\x08\x12\x1b\n\x0etransaction_id\x18\x06 \x01(\x0cH\x02\x88\x01\x01\x12P\n\x07options\x18\xe8\x07 \x03(\x0b\x32>.arrow.flight.protocol.sql.CommandStatementIngest.OptionsEntry\x1a\x99\x04\n\x16TableDefinitionOptions\x12r\n\x0cif_not_exist\x18\x01 \x01(\x0e\x32\\.arrow.flight.protocol.sql.CommandStatementIngest.TableDefinitionOptions.TableNotExistOption\x12m\n\tif_exists\x18\x02 \x01(\x0e\x32Z.arrow.flight.protocol.sql.CommandStatementIngest.TableDefinitionOptions.TableExistsOption\"\x81\x01\n\x13TableNotExistOption\x12&\n\"TABLE_NOT_EXIST_OPTION_UNSPECIFIED\x10\x00\x12!\n\x1dTABLE_NOT_EXIST_OPTION_CREATE\x10\x01\x12\x1f\n\x1bTABLE_NOT_EXIST_OPTION_FAIL\x10\x02\"\x97\x01\n\x11TableExistsOption\x12#\n\x1fTABLE_EXISTS_OPTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18TABLE_EXISTS_OPTION_FAIL\x10\x01\x12\x1e\n\x1aTABLE_EXISTS_OPTION_APPEND\x10\x02\x12\x1f\n\x1bTABLE_EXISTS_OPTION_REPLACE\x10\x03\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07_schemaB\n\n\x08_catalogB\x11\n\x0f_transaction_id\")\n\x11\x44oPutUpdateResult\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\"d\n\x1c\x44oPutPreparedStatementResult\x12&\n\x19prepared_statement_handle\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x42\x1c\n\x1a_prepared_statement_handle\",\n\x18\x41\x63tionCancelQueryRequest\x12\x0c\n\x04info\x18\x01 \x01(\x0c:\x02\x18\x01\"\xfc\x01\n\x17\x41\x63tionCancelQueryResult\x12O\n\x06result\x18\x01 \x01(\x0e\x32?.arrow.flight.protocol.sql.ActionCancelQueryResult.CancelResult\"\x8b\x01\n\x0c\x43\x61ncelResult\x12\x1d\n\x19\x43\x41NCEL_RESULT_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43\x41NCEL_RESULT_CANCELLED\x10\x01\x12\x1c\n\x18\x43\x41NCEL_RESULT_CANCELLING\x10\x02\x12!\n\x1d\x43\x41NCEL_RESULT_NOT_CANCELLABLE\x10\x03:\x02\x18\x01*\x92\x19\n\x07SqlInfo\x12\x1a\n\x16\x46LIGHT_SQL_SERVER_NAME\x10\x00\x12\x1d\n\x19\x46LIGHT_SQL_SERVER_VERSION\x10\x01\x12#\n\x1f\x46LIGHT_SQL_SERVER_ARROW_VERSION\x10\x02\x12\x1f\n\x1b\x46LIGHT_SQL_SERVER_READ_ONLY\x10\x03\x12\x19\n\x15\x46LIGHT_SQL_SERVER_SQL\x10\x04\x12\x1f\n\x1b\x46LIGHT_SQL_SERVER_SUBSTRAIT\x10\x05\x12+\n\'FLIGHT_SQL_SERVER_SUBSTRAIT_MIN_VERSION\x10\x06\x12+\n\'FLIGHT_SQL_SERVER_SUBSTRAIT_MAX_VERSION\x10\x07\x12!\n\x1d\x46LIGHT_SQL_SERVER_TRANSACTION\x10\x08\x12\x1c\n\x18\x46LIGHT_SQL_SERVER_CANCEL\x10\t\x12$\n FLIGHT_SQL_SERVER_BULK_INGESTION\x10\n\x12\x33\n/FLIGHT_SQL_SERVER_INGEST_TRANSACTIONS_SUPPORTED\x10\x0b\x12\'\n#FLIGHT_SQL_SERVER_STATEMENT_TIMEOUT\x10\x64\x12)\n%FLIGHT_SQL_SERVER_TRANSACTION_TIMEOUT\x10\x65\x12\x14\n\x0fSQL_DDL_CATALOG\x10\xf4\x03\x12\x13\n\x0eSQL_DDL_SCHEMA\x10\xf5\x03\x12\x12\n\rSQL_DDL_TABLE\x10\xf6\x03\x12\x18\n\x13SQL_IDENTIFIER_CASE\x10\xf7\x03\x12\x1e\n\x19SQL_IDENTIFIER_QUOTE_CHAR\x10\xf8\x03\x12\x1f\n\x1aSQL_QUOTED_IDENTIFIER_CASE\x10\xf9\x03\x12\"\n\x1dSQL_ALL_TABLES_ARE_SELECTABLE\x10\xfa\x03\x12\x16\n\x11SQL_NULL_ORDERING\x10\xfb\x03\x12\x11\n\x0cSQL_KEYWORDS\x10\xfc\x03\x12\x1a\n\x15SQL_NUMERIC_FUNCTIONS\x10\xfd\x03\x12\x19\n\x14SQL_STRING_FUNCTIONS\x10\xfe\x03\x12\x19\n\x14SQL_SYSTEM_FUNCTIONS\x10\xff\x03\x12\x1b\n\x16SQL_DATETIME_FUNCTIONS\x10\x80\x04\x12\x1d\n\x18SQL_SEARCH_STRING_ESCAPE\x10\x81\x04\x12\x1e\n\x19SQL_EXTRA_NAME_CHARACTERS\x10\x82\x04\x12!\n\x1cSQL_SUPPORTS_COLUMN_ALIASING\x10\x83\x04\x12\x1f\n\x1aSQL_NULL_PLUS_NULL_IS_NULL\x10\x84\x04\x12\x19\n\x14SQL_SUPPORTS_CONVERT\x10\x85\x04\x12)\n$SQL_SUPPORTS_TABLE_CORRELATION_NAMES\x10\x86\x04\x12\x33\n.SQL_SUPPORTS_DIFFERENT_TABLE_CORRELATION_NAMES\x10\x87\x04\x12)\n$SQL_SUPPORTS_EXPRESSIONS_IN_ORDER_BY\x10\x88\x04\x12$\n\x1fSQL_SUPPORTS_ORDER_BY_UNRELATED\x10\x89\x04\x12\x1b\n\x16SQL_SUPPORTED_GROUP_BY\x10\x8a\x04\x12$\n\x1fSQL_SUPPORTS_LIKE_ESCAPE_CLAUSE\x10\x8b\x04\x12&\n!SQL_SUPPORTS_NON_NULLABLE_COLUMNS\x10\x8c\x04\x12\x1a\n\x15SQL_SUPPORTED_GRAMMAR\x10\x8d\x04\x12\x1f\n\x1aSQL_ANSI92_SUPPORTED_LEVEL\x10\x8e\x04\x12\x30\n+SQL_SUPPORTS_INTEGRITY_ENHANCEMENT_FACILITY\x10\x8f\x04\x12\"\n\x1dSQL_OUTER_JOINS_SUPPORT_LEVEL\x10\x90\x04\x12\x14\n\x0fSQL_SCHEMA_TERM\x10\x91\x04\x12\x17\n\x12SQL_PROCEDURE_TERM\x10\x92\x04\x12\x15\n\x10SQL_CATALOG_TERM\x10\x93\x04\x12\x19\n\x14SQL_CATALOG_AT_START\x10\x94\x04\x12\"\n\x1dSQL_SCHEMAS_SUPPORTED_ACTIONS\x10\x95\x04\x12#\n\x1eSQL_CATALOGS_SUPPORTED_ACTIONS\x10\x96\x04\x12&\n!SQL_SUPPORTED_POSITIONED_COMMANDS\x10\x97\x04\x12$\n\x1fSQL_SELECT_FOR_UPDATE_SUPPORTED\x10\x98\x04\x12$\n\x1fSQL_STORED_PROCEDURES_SUPPORTED\x10\x99\x04\x12\x1d\n\x18SQL_SUPPORTED_SUBQUERIES\x10\x9a\x04\x12(\n#SQL_CORRELATED_SUBQUERIES_SUPPORTED\x10\x9b\x04\x12\x19\n\x14SQL_SUPPORTED_UNIONS\x10\x9c\x04\x12\"\n\x1dSQL_MAX_BINARY_LITERAL_LENGTH\x10\x9d\x04\x12 \n\x1bSQL_MAX_CHAR_LITERAL_LENGTH\x10\x9e\x04\x12\x1f\n\x1aSQL_MAX_COLUMN_NAME_LENGTH\x10\x9f\x04\x12 \n\x1bSQL_MAX_COLUMNS_IN_GROUP_BY\x10\xa0\x04\x12\x1d\n\x18SQL_MAX_COLUMNS_IN_INDEX\x10\xa1\x04\x12 \n\x1bSQL_MAX_COLUMNS_IN_ORDER_BY\x10\xa2\x04\x12\x1e\n\x19SQL_MAX_COLUMNS_IN_SELECT\x10\xa3\x04\x12\x1d\n\x18SQL_MAX_COLUMNS_IN_TABLE\x10\xa4\x04\x12\x18\n\x13SQL_MAX_CONNECTIONS\x10\xa5\x04\x12\x1f\n\x1aSQL_MAX_CURSOR_NAME_LENGTH\x10\xa6\x04\x12\x19\n\x14SQL_MAX_INDEX_LENGTH\x10\xa7\x04\x12\x1e\n\x19SQL_DB_SCHEMA_NAME_LENGTH\x10\xa8\x04\x12\"\n\x1dSQL_MAX_PROCEDURE_NAME_LENGTH\x10\xa9\x04\x12 \n\x1bSQL_MAX_CATALOG_NAME_LENGTH\x10\xaa\x04\x12\x15\n\x10SQL_MAX_ROW_SIZE\x10\xab\x04\x12$\n\x1fSQL_MAX_ROW_SIZE_INCLUDES_BLOBS\x10\xac\x04\x12\x1d\n\x18SQL_MAX_STATEMENT_LENGTH\x10\xad\x04\x12\x17\n\x12SQL_MAX_STATEMENTS\x10\xae\x04\x12\x1e\n\x19SQL_MAX_TABLE_NAME_LENGTH\x10\xaf\x04\x12\x1d\n\x18SQL_MAX_TABLES_IN_SELECT\x10\xb0\x04\x12\x1c\n\x17SQL_MAX_USERNAME_LENGTH\x10\xb1\x04\x12&\n!SQL_DEFAULT_TRANSACTION_ISOLATION\x10\xb2\x04\x12\x1f\n\x1aSQL_TRANSACTIONS_SUPPORTED\x10\xb3\x04\x12\x30\n+SQL_SUPPORTED_TRANSACTIONS_ISOLATION_LEVELS\x10\xb4\x04\x12\x32\n-SQL_DATA_DEFINITION_CAUSES_TRANSACTION_COMMIT\x10\xb5\x04\x12\x31\n,SQL_DATA_DEFINITIONS_IN_TRANSACTIONS_IGNORED\x10\xb6\x04\x12#\n\x1eSQL_SUPPORTED_RESULT_SET_TYPES\x10\xb7\x04\x12;\n6SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_UNSPECIFIED\x10\xb8\x04\x12<\n7SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_FORWARD_ONLY\x10\xb9\x04\x12@\n;SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_SCROLL_SENSITIVE\x10\xba\x04\x12\x42\n=SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_SCROLL_INSENSITIVE\x10\xbb\x04\x12 \n\x1bSQL_BATCH_UPDATES_SUPPORTED\x10\xbc\x04\x12\x1d\n\x18SQL_SAVEPOINTS_SUPPORTED\x10\xbd\x04\x12#\n\x1eSQL_NAMED_PARAMETERS_SUPPORTED\x10\xbe\x04\x12\x1d\n\x18SQL_LOCATORS_UPDATE_COPY\x10\xbf\x04\x12\x35\n0SQL_STORED_FUNCTIONS_USING_CALL_SYNTAX_SUPPORTED\x10\xc0\x04*\x91\x01\n\x17SqlSupportedTransaction\x12\"\n\x1eSQL_SUPPORTED_TRANSACTION_NONE\x10\x00\x12)\n%SQL_SUPPORTED_TRANSACTION_TRANSACTION\x10\x01\x12\'\n#SQL_SUPPORTED_TRANSACTION_SAVEPOINT\x10\x02*\xb2\x01\n\x1bSqlSupportedCaseSensitivity\x12 \n\x1cSQL_CASE_SENSITIVITY_UNKNOWN\x10\x00\x12)\n%SQL_CASE_SENSITIVITY_CASE_INSENSITIVE\x10\x01\x12\"\n\x1eSQL_CASE_SENSITIVITY_UPPERCASE\x10\x02\x12\"\n\x1eSQL_CASE_SENSITIVITY_LOWERCASE\x10\x03*\x82\x01\n\x0fSqlNullOrdering\x12\x19\n\x15SQL_NULLS_SORTED_HIGH\x10\x00\x12\x18\n\x14SQL_NULLS_SORTED_LOW\x10\x01\x12\x1d\n\x19SQL_NULLS_SORTED_AT_START\x10\x02\x12\x1b\n\x17SQL_NULLS_SORTED_AT_END\x10\x03*^\n\x13SupportedSqlGrammar\x12\x17\n\x13SQL_MINIMUM_GRAMMAR\x10\x00\x12\x14\n\x10SQL_CORE_GRAMMAR\x10\x01\x12\x18\n\x14SQL_EXTENDED_GRAMMAR\x10\x02*h\n\x1eSupportedAnsi92SqlGrammarLevel\x12\x14\n\x10\x41NSI92_ENTRY_SQL\x10\x00\x12\x1b\n\x17\x41NSI92_INTERMEDIATE_SQL\x10\x01\x12\x13\n\x0f\x41NSI92_FULL_SQL\x10\x02*m\n\x19SqlOuterJoinsSupportLevel\x12\x19\n\x15SQL_JOINS_UNSUPPORTED\x10\x00\x12\x1b\n\x17SQL_LIMITED_OUTER_JOINS\x10\x01\x12\x18\n\x14SQL_FULL_OUTER_JOINS\x10\x02*Q\n\x13SqlSupportedGroupBy\x12\x1a\n\x16SQL_GROUP_BY_UNRELATED\x10\x00\x12\x1e\n\x1aSQL_GROUP_BY_BEYOND_SELECT\x10\x01*\x90\x01\n\x1aSqlSupportedElementActions\x12\"\n\x1eSQL_ELEMENT_IN_PROCEDURE_CALLS\x10\x00\x12$\n SQL_ELEMENT_IN_INDEX_DEFINITIONS\x10\x01\x12(\n$SQL_ELEMENT_IN_PRIVILEGE_DEFINITIONS\x10\x02*V\n\x1eSqlSupportedPositionedCommands\x12\x19\n\x15SQL_POSITIONED_DELETE\x10\x00\x12\x19\n\x15SQL_POSITIONED_UPDATE\x10\x01*\x97\x01\n\x16SqlSupportedSubqueries\x12!\n\x1dSQL_SUBQUERIES_IN_COMPARISONS\x10\x00\x12\x1c\n\x18SQL_SUBQUERIES_IN_EXISTS\x10\x01\x12\x19\n\x15SQL_SUBQUERIES_IN_INS\x10\x02\x12!\n\x1dSQL_SUBQUERIES_IN_QUANTIFIEDS\x10\x03*6\n\x12SqlSupportedUnions\x12\r\n\tSQL_UNION\x10\x00\x12\x11\n\rSQL_UNION_ALL\x10\x01*\xc9\x01\n\x1cSqlTransactionIsolationLevel\x12\x18\n\x14SQL_TRANSACTION_NONE\x10\x00\x12$\n SQL_TRANSACTION_READ_UNCOMMITTED\x10\x01\x12\"\n\x1eSQL_TRANSACTION_READ_COMMITTED\x10\x02\x12#\n\x1fSQL_TRANSACTION_REPEATABLE_READ\x10\x03\x12 \n\x1cSQL_TRANSACTION_SERIALIZABLE\x10\x04*\x89\x01\n\x18SqlSupportedTransactions\x12\x1f\n\x1bSQL_TRANSACTION_UNSPECIFIED\x10\x00\x12$\n SQL_DATA_DEFINITION_TRANSACTIONS\x10\x01\x12&\n\"SQL_DATA_MANIPULATION_TRANSACTIONS\x10\x02*\xbc\x01\n\x19SqlSupportedResultSetType\x12#\n\x1fSQL_RESULT_SET_TYPE_UNSPECIFIED\x10\x00\x12$\n SQL_RESULT_SET_TYPE_FORWARD_ONLY\x10\x01\x12*\n&SQL_RESULT_SET_TYPE_SCROLL_INSENSITIVE\x10\x02\x12(\n$SQL_RESULT_SET_TYPE_SCROLL_SENSITIVE\x10\x03*\xa2\x01\n SqlSupportedResultSetConcurrency\x12*\n&SQL_RESULT_SET_CONCURRENCY_UNSPECIFIED\x10\x00\x12(\n$SQL_RESULT_SET_CONCURRENCY_READ_ONLY\x10\x01\x12(\n$SQL_RESULT_SET_CONCURRENCY_UPDATABLE\x10\x02*\x99\x04\n\x12SqlSupportsConvert\x12\x16\n\x12SQL_CONVERT_BIGINT\x10\x00\x12\x16\n\x12SQL_CONVERT_BINARY\x10\x01\x12\x13\n\x0fSQL_CONVERT_BIT\x10\x02\x12\x14\n\x10SQL_CONVERT_CHAR\x10\x03\x12\x14\n\x10SQL_CONVERT_DATE\x10\x04\x12\x17\n\x13SQL_CONVERT_DECIMAL\x10\x05\x12\x15\n\x11SQL_CONVERT_FLOAT\x10\x06\x12\x17\n\x13SQL_CONVERT_INTEGER\x10\x07\x12!\n\x1dSQL_CONVERT_INTERVAL_DAY_TIME\x10\x08\x12#\n\x1fSQL_CONVERT_INTERVAL_YEAR_MONTH\x10\t\x12\x1d\n\x19SQL_CONVERT_LONGVARBINARY\x10\n\x12\x1b\n\x17SQL_CONVERT_LONGVARCHAR\x10\x0b\x12\x17\n\x13SQL_CONVERT_NUMERIC\x10\x0c\x12\x14\n\x10SQL_CONVERT_REAL\x10\r\x12\x18\n\x14SQL_CONVERT_SMALLINT\x10\x0e\x12\x14\n\x10SQL_CONVERT_TIME\x10\x0f\x12\x19\n\x15SQL_CONVERT_TIMESTAMP\x10\x10\x12\x17\n\x13SQL_CONVERT_TINYINT\x10\x11\x12\x19\n\x15SQL_CONVERT_VARBINARY\x10\x12\x12\x17\n\x13SQL_CONVERT_VARCHAR\x10\x13*\x8f\x04\n\x0cXdbcDataType\x12\x15\n\x11XDBC_UNKNOWN_TYPE\x10\x00\x12\r\n\tXDBC_CHAR\x10\x01\x12\x10\n\x0cXDBC_NUMERIC\x10\x02\x12\x10\n\x0cXDBC_DECIMAL\x10\x03\x12\x10\n\x0cXDBC_INTEGER\x10\x04\x12\x11\n\rXDBC_SMALLINT\x10\x05\x12\x0e\n\nXDBC_FLOAT\x10\x06\x12\r\n\tXDBC_REAL\x10\x07\x12\x0f\n\x0bXDBC_DOUBLE\x10\x08\x12\x11\n\rXDBC_DATETIME\x10\t\x12\x11\n\rXDBC_INTERVAL\x10\n\x12\x10\n\x0cXDBC_VARCHAR\x10\x0c\x12\r\n\tXDBC_DATE\x10[\x12\r\n\tXDBC_TIME\x10\\\x12\x12\n\x0eXDBC_TIMESTAMP\x10]\x12\x1d\n\x10XDBC_LONGVARCHAR\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x0bXDBC_BINARY\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1b\n\x0eXDBC_VARBINARY\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12XDBC_LONGVARBINARY\x10\xfc\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x0bXDBC_BIGINT\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x19\n\x0cXDBC_TINYINT\x10\xfa\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x08XDBC_BIT\x10\xf9\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x17\n\nXDBC_WCHAR\x10\xf8\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\rXDBC_WVARCHAR\x10\xf7\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xa3\x08\n\x13XdbcDatetimeSubcode\x12\x18\n\x14XDBC_SUBCODE_UNKNOWN\x10\x00\x12\x15\n\x11XDBC_SUBCODE_YEAR\x10\x01\x12\x15\n\x11XDBC_SUBCODE_DATE\x10\x01\x12\x15\n\x11XDBC_SUBCODE_TIME\x10\x02\x12\x16\n\x12XDBC_SUBCODE_MONTH\x10\x02\x12\x1a\n\x16XDBC_SUBCODE_TIMESTAMP\x10\x03\x12\x14\n\x10XDBC_SUBCODE_DAY\x10\x03\x12#\n\x1fXDBC_SUBCODE_TIME_WITH_TIMEZONE\x10\x04\x12\x15\n\x11XDBC_SUBCODE_HOUR\x10\x04\x12(\n$XDBC_SUBCODE_TIMESTAMP_WITH_TIMEZONE\x10\x05\x12\x17\n\x13XDBC_SUBCODE_MINUTE\x10\x05\x12\x17\n\x13XDBC_SUBCODE_SECOND\x10\x06\x12\x1e\n\x1aXDBC_SUBCODE_YEAR_TO_MONTH\x10\x07\x12\x1c\n\x18XDBC_SUBCODE_DAY_TO_HOUR\x10\x08\x12\x1e\n\x1aXDBC_SUBCODE_DAY_TO_MINUTE\x10\t\x12\x1e\n\x1aXDBC_SUBCODE_DAY_TO_SECOND\x10\n\x12\x1f\n\x1bXDBC_SUBCODE_HOUR_TO_MINUTE\x10\x0b\x12\x1f\n\x1bXDBC_SUBCODE_HOUR_TO_SECOND\x10\x0c\x12!\n\x1dXDBC_SUBCODE_MINUTE_TO_SECOND\x10\r\x12\x1e\n\x1aXDBC_SUBCODE_INTERVAL_YEAR\x10\x65\x12\x1f\n\x1bXDBC_SUBCODE_INTERVAL_MONTH\x10\x66\x12\x1d\n\x19XDBC_SUBCODE_INTERVAL_DAY\x10g\x12\x1e\n\x1aXDBC_SUBCODE_INTERVAL_HOUR\x10h\x12 \n\x1cXDBC_SUBCODE_INTERVAL_MINUTE\x10i\x12 \n\x1cXDBC_SUBCODE_INTERVAL_SECOND\x10j\x12\'\n#XDBC_SUBCODE_INTERVAL_YEAR_TO_MONTH\x10k\x12%\n!XDBC_SUBCODE_INTERVAL_DAY_TO_HOUR\x10l\x12\'\n#XDBC_SUBCODE_INTERVAL_DAY_TO_MINUTE\x10m\x12\'\n#XDBC_SUBCODE_INTERVAL_DAY_TO_SECOND\x10n\x12(\n$XDBC_SUBCODE_INTERVAL_HOUR_TO_MINUTE\x10o\x12(\n$XDBC_SUBCODE_INTERVAL_HOUR_TO_SECOND\x10p\x12*\n&XDBC_SUBCODE_INTERVAL_MINUTE_TO_SECOND\x10q\x1a\x02\x10\x01*W\n\x08Nullable\x12\x18\n\x14NULLABILITY_NO_NULLS\x10\x00\x12\x18\n\x14NULLABILITY_NULLABLE\x10\x01\x12\x17\n\x13NULLABILITY_UNKNOWN\x10\x02*a\n\nSearchable\x12\x13\n\x0fSEARCHABLE_NONE\x10\x00\x12\x13\n\x0fSEARCHABLE_CHAR\x10\x01\x12\x14\n\x10SEARCHABLE_BASIC\x10\x02\x12\x13\n\x0fSEARCHABLE_FULL\x10\x03*\\\n\x11UpdateDeleteRules\x12\x0b\n\x07\x43\x41SCADE\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0c\n\x08SET_NULL\x10\x02\x12\r\n\tNO_ACTION\x10\x03\x12\x0f\n\x0bSET_DEFAULT\x10\x04:6\n\x0c\x65xperimental\x12\x1f.google.protobuf.MessageOptions\x18\xe8\x07 \x01(\x08\x42V\n org.apache.arrow.flight.sql.implZ2github.com/apache/arrow-go/arrow/flight/gen/flightb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FlightSql_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.apache.arrow.flight.sql.implZ2github.com/apache/arrow-go/arrow/flight/gen/flight'
  _globals['_XDBCDATETIMESUBCODE']._loaded_options = None
  _globals['_XDBCDATETIMESUBCODE']._serialized_options = b'\020\001'
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._loaded_options = None
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_ACTIONCANCELQUERYREQUEST']._loaded_options = None
  _globals['_ACTIONCANCELQUERYREQUEST']._serialized_options = b'\030\001'
  _globals['_ACTIONCANCELQUERYRESULT']._loaded_options = None
  _globals['_ACTIONCANCELQUERYRESULT']._serialized_options = b'\030\001'
  _globals['_SQLINFO']._serialized_start=4258
  _globals['_SQLINFO']._serialized_end=7476
  _globals['_SQLSUPPORTEDTRANSACTION']._serialized_start=7479
  _globals['_SQLSUPPORTEDTRANSACTION']._serialized_end=7624
  _globals['_SQLSUPPORTEDCASESENSITIVITY']._serialized_start=7627
  _globals['_SQLSUPPORTEDCASESENSITIVITY']._serialized_end=7805
  _globals['_SQLNULLORDERING']._serialized_start=7808
  _globals['_SQLNULLORDERING']._serialized_end=7938
  _globals['_SUPPORTEDSQLGRAMMAR']._serialized_start=7940
  _globals['_SUPPORTEDSQLGRAMMAR']._serialized_end=8034
  _globals['_SUPPORTEDANSI92SQLGRAMMARLEVEL']._serialized_start=8036
  _globals['_SUPPORTEDANSI92SQLGRAMMARLEVEL']._serialized_end=8140
  _globals['_SQLOUTERJOINSSUPPORTLEVEL']._serialized_start=8142
  _globals['_SQLOUTERJOINSSUPPORTLEVEL']._serialized_end=8251
  _globals['_SQLSUPPORTEDGROUPBY']._serialized_start=8253
  _globals['_SQLSUPPORTEDGROUPBY']._serialized_end=8334
  _globals['_SQLSUPPORTEDELEMENTACTIONS']._serialized_start=8337
  _globals['_SQLSUPPORTEDELEMENTACTIONS']._serialized_end=8481
  _globals['_SQLSUPPORTEDPOSITIONEDCOMMANDS']._serialized_start=8483
  _globals['_SQLSUPPORTEDPOSITIONEDCOMMANDS']._serialized_end=8569
  _globals['_SQLSUPPORTEDSUBQUERIES']._serialized_start=8572
  _globals['_SQLSUPPORTEDSUBQUERIES']._serialized_end=8723
  _globals['_SQLSUPPORTEDUNIONS']._serialized_start=8725
  _globals['_SQLSUPPORTEDUNIONS']._serialized_end=8779
  _globals['_SQLTRANSACTIONISOLATIONLEVEL']._serialized_start=8782
  _globals['_SQLTRANSACTIONISOLATIONLEVEL']._serialized_end=8983
  _globals['_SQLSUPPORTEDTRANSACTIONS']._serialized_start=8986
  _globals['_SQLSUPPORTEDTRANSACTIONS']._serialized_end=9123
  _globals['_SQLSUPPORTEDRESULTSETTYPE']._serialized_start=9126
  _globals['_SQLSUPPORTEDRESULTSETTYPE']._serialized_end=9314
  _globals['_SQLSUPPORTEDRESULTSETCONCURRENCY']._serialized_start=9317
  _globals['_SQLSUPPORTEDRESULTSETCONCURRENCY']._serialized_end=9479
  _globals['_SQLSUPPORTSCONVERT']._serialized_start=9482
  _globals['_SQLSUPPORTSCONVERT']._serialized_end=10019
  _globals['_XDBCDATATYPE']._serialized_start=10022
  _globals['_XDBCDATATYPE']._serialized_end=10549
  _globals['_XDBCDATETIMESUBCODE']._serialized_start=10552
  _globals['_XDBCDATETIMESUBCODE']._serialized_end=11611
  _globals['_NULLABLE']._serialized_start=11613
  _globals['_NULLABLE']._serialized_end=11700
  _globals['_SEARCHABLE']._serialized_start=11702
  _globals['_SEARCHABLE']._serialized_end=11799
  _globals['_UPDATEDELETERULES']._serialized_start=11801
  _globals['_UPDATEDELETERULES']._serialized_end=11893
  _globals['_COMMANDGETSQLINFO']._serialized_start=80
  _globals['_COMMANDGETSQLINFO']._serialized_end=113
  _globals['_COMMANDGETXDBCTYPEINFO']._serialized_start=115
  _globals['_COMMANDGETXDBCTYPEINFO']._serialized_end=177
  _globals['_COMMANDGETCATALOGS']._serialized_start=179
  _globals['_COMMANDGETCATALOGS']._serialized_end=199
  _globals['_COMMANDGETDBSCHEMAS']._serialized_start=201
  _globals['_COMMANDGETDBSCHEMAS']._serialized_end=324
  _globals['_COMMANDGETTABLES']._serialized_start=327
  _globals['_COMMANDGETTABLES']._serialized_end=562
  _globals['_COMMANDGETTABLETYPES']._serialized_start=564
  _globals['_COMMANDGETTABLETYPES']._serialized_end=586
  _globals['_COMMANDGETPRIMARYKEYS']._serialized_start=588
  _globals['_COMMANDGETPRIMARYKEYS']._serialized_end=698
  _globals['_COMMANDGETEXPORTEDKEYS']._serialized_start=700
  _globals['_COMMANDGETEXPORTEDKEYS']._serialized_end=811
  _globals['_COMMANDGETIMPORTEDKEYS']._serialized_start=813
  _globals['_COMMANDGETIMPORTEDKEYS']._serialized_end=924
  _globals['_COMMANDGETCROSSREFERENCE']._serialized_start=927
  _globals['_COMMANDGETCROSSREFERENCE']._serialized_end=1157
  _globals['_ACTIONCREATEPREPAREDSTATEMENTREQUEST']._serialized_start=1159
  _globals['_ACTIONCREATEPREPAREDSTATEMENTREQUEST']._serialized_end=1260
  _globals['_SUBSTRAITPLAN']._serialized_start=1262
  _globals['_SUBSTRAITPLAN']._serialized_end=1308
  _globals['_ACTIONCREATEPREPAREDSUBSTRAITPLANREQUEST']._serialized_start=1311
  _globals['_ACTIONCREATEPREPAREDSUBSTRAITPLANREQUEST']._serialized_end=1457
  _globals['_ACTIONCREATEPREPAREDSTATEMENTRESULT']._serialized_start=1459
  _globals['_ACTIONCREATEPREPAREDSTATEMENTRESULT']._serialized_end=1581
  _globals['_ACTIONCLOSEPREPAREDSTATEMENTREQUEST']._serialized_start=1583
  _globals['_ACTIONCLOSEPREPAREDSTATEMENTREQUEST']._serialized_end=1655
  _globals['_ACTIONBEGINTRANSACTIONREQUEST']._serialized_start=1657
  _globals['_ACTIONBEGINTRANSACTIONREQUEST']._serialized_end=1688
  _globals['_ACTIONBEGINSAVEPOINTREQUEST']._serialized_start=1690
  _globals['_ACTIONBEGINSAVEPOINTREQUEST']._serialized_end=1757
  _globals['_ACTIONBEGINTRANSACTIONRESULT']._serialized_start=1759
  _globals['_ACTIONBEGINTRANSACTIONRESULT']._serialized_end=1813
  _globals['_ACTIONBEGINSAVEPOINTRESULT']._serialized_start=1815
  _globals['_ACTIONBEGINSAVEPOINTRESULT']._serialized_end=1865
  _globals['_ACTIONENDTRANSACTIONREQUEST']._serialized_start=1868
  _globals['_ACTIONENDTRANSACTIONREQUEST']._serialized_end=2117
  _globals['_ACTIONENDTRANSACTIONREQUEST_ENDTRANSACTION']._serialized_start=2010
  _globals['_ACTIONENDTRANSACTIONREQUEST_ENDTRANSACTION']._serialized_end=2117
  _globals['_ACTIONENDSAVEPOINTREQUEST']._serialized_start=2120
  _globals['_ACTIONENDSAVEPOINTREQUEST']._serialized_end=2354
  _globals['_ACTIONENDSAVEPOINTREQUEST_ENDSAVEPOINT']._serialized_start=2254
  _globals['_ACTIONENDSAVEPOINTREQUEST_ENDSAVEPOINT']._serialized_end=2354
  _globals['_COMMANDSTATEMENTQUERY']._serialized_start=2356
  _globals['_COMMANDSTATEMENTQUERY']._serialized_end=2442
  _globals['_COMMANDSTATEMENTSUBSTRAITPLAN']._serialized_start=2445
  _globals['_COMMANDSTATEMENTSUBSTRAITPLAN']._serialized_end=2580
  _globals['_TICKETSTATEMENTQUERY']._serialized_start=2582
  _globals['_TICKETSTATEMENTQUERY']._serialized_end=2630
  _globals['_COMMANDPREPAREDSTATEMENTQUERY']._serialized_start=2632
  _globals['_COMMANDPREPAREDSTATEMENTQUERY']._serialized_end=2698
  _globals['_COMMANDSTATEMENTUPDATE']._serialized_start=2700
  _globals['_COMMANDSTATEMENTUPDATE']._serialized_end=2787
  _globals['_COMMANDPREPAREDSTATEMENTUPDATE']._serialized_start=2789
  _globals['_COMMANDPREPAREDSTATEMENTUPDATE']._serialized_end=2856
  _globals['_COMMANDSTATEMENTINGEST']._serialized_start=2859
  _globals['_COMMANDSTATEMENTINGEST']._serialized_end=3809
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS']._serialized_start=3182
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS']._serialized_end=3719
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLENOTEXISTOPTION']._serialized_start=3436
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLENOTEXISTOPTION']._serialized_end=3565
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLEEXISTSOPTION']._serialized_start=3568
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLEEXISTSOPTION']._serialized_end=3719
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._serialized_start=3721
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._serialized_end=3767
  _globals['_DOPUTUPDATERESULT']._serialized_start=3811
  _globals['_DOPUTUPDATERESULT']._serialized_end=3852
  _globals['_DOPUTPREPAREDSTATEMENTRESULT']._serialized_start=3854
  _globals['_DOPUTPREPAREDSTATEMENTRESULT']._serialized_end=3954
  _globals['_ACTIONCANCELQUERYREQUEST']._serialized_start=3956
  _globals['_ACTIONCANCELQUERYREQUEST']._serialized_end=4000
  _globals['_ACTIONCANCELQUERYRESULT']._serialized_start=4003
  _globals['_ACTIONCANCELQUERYRESULT']._serialized_end=4255
  _globals['_ACTIONCANCELQUERYRESULT_CANCELRESULT']._serialized_start=4112
  _globals['_ACTIONCANCELQUERYRESULT_CANCELRESULT']._serialized_end=4251
# @@protoc_insertion_point(module_scope)
