# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/mali.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/mali.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'protos/perfetto/trace/ftrace/mali.proto\x12\x0fperfetto.protos\"Y\n\x1fMaliTracingMarkWriteFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\r\x12\r\n\x05value\x18\x04 \x01(\x05\"u\n\x1dMaliMaliKCPUCQSSETFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x11\n\tinfo_val1\x18\x02 \x01(\x04\x12\x11\n\tinfo_val2\x18\x03 \x01(\x04\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\x11\n\tkctx_tgid\x18\x05 \x01(\x05\"{\n#MaliMaliKCPUCQSWAITSTARTFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x11\n\tinfo_val1\x18\x02 \x01(\x04\x12\x11\n\tinfo_val2\x18\x03 \x01(\x04\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\x11\n\tkctx_tgid\x18\x05 \x01(\x05\"y\n!MaliMaliKCPUCQSWAITENDFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x11\n\tinfo_val1\x18\x02 \x01(\x04\x12\x11\n\tinfo_val2\x18\x03 \x01(\x04\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\x11\n\tkctx_tgid\x18\x05 \x01(\x05\"z\n\"MaliMaliKCPUFENCESIGNALFtraceEvent\x12\x11\n\tinfo_val1\x18\x01 \x01(\x04\x12\x11\n\tinfo_val2\x18\x02 \x01(\x04\x12\x11\n\tkctx_tgid\x18\x03 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\"}\n%MaliMaliKCPUFENCEWAITSTARTFtraceEvent\x12\x11\n\tinfo_val1\x18\x01 \x01(\x04\x12\x11\n\tinfo_val2\x18\x02 \x01(\x04\x12\x11\n\tkctx_tgid\x18\x03 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\"{\n#MaliMaliKCPUFENCEWAITENDFtraceEvent\x12\x11\n\tinfo_val1\x18\x01 \x01(\x04\x12\x11\n\tinfo_val2\x18\x02 \x01(\x04\x12\x11\n\tkctx_tgid\x18\x03 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\"\\\n$MaliMaliCSFINTERRUPTSTARTFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Z\n\"MaliMaliCSFINTERRUPTENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"l\n4MaliMaliPMMCUHCTLCORESDOWNSCALENOTIFYPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"c\n+MaliMaliPMMCUHCTLCORESNOTIFYPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"d\n,MaliMaliPMMCUHCTLCOREINACTIVEPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"`\n(MaliMaliPMMCUHCTLMCUONRECHECKFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"f\n.MaliMaliPMMCUHCTLSHADERSCOREOFFPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"b\n*MaliMaliPMMCUHCTLSHADERSPENDOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"a\n)MaliMaliPMMCUHCTLSHADERSPENDONFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"c\n+MaliMaliPMMCUHCTLSHADERSREADYOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"W\n\x1fMaliMaliPMMCUINSLEEPFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"S\n\x1bMaliMaliPMMCUOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"R\n\x1aMaliMaliPMMCUONFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"d\n,MaliMaliPMMCUONCOREATTRUPDATEPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"_\n\'MaliMaliPMMCUONGLBREINITPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"V\n\x1eMaliMaliPMMCUONHALTFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"^\n&MaliMaliPMMCUONHWCNTDISABLEFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"]\n%MaliMaliPMMCUONHWCNTENABLEFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Z\n\"MaliMaliPMMCUONPENDHALTFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"[\n#MaliMaliPMMCUONPENDSLEEPFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"_\n\'MaliMaliPMMCUONSLEEPINITIATEFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"W\n\x1fMaliMaliPMMCUPENDOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"\\\n$MaliMaliPMMCUPENDONRELOADFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Y\n!MaliMaliPMMCUPOWERDOWNFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Y\n!MaliMaliPMMCURESETWAITFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.mali_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MALITRACINGMARKWRITEFTRACEEVENT']._serialized_start=60
  _globals['_MALITRACINGMARKWRITEFTRACEEVENT']._serialized_end=149
  _globals['_MALIMALIKCPUCQSSETFTRACEEVENT']._serialized_start=151
  _globals['_MALIMALIKCPUCQSSETFTRACEEVENT']._serialized_end=268
  _globals['_MALIMALIKCPUCQSWAITSTARTFTRACEEVENT']._serialized_start=270
  _globals['_MALIMALIKCPUCQSWAITSTARTFTRACEEVENT']._serialized_end=393
  _globals['_MALIMALIKCPUCQSWAITENDFTRACEEVENT']._serialized_start=395
  _globals['_MALIMALIKCPUCQSWAITENDFTRACEEVENT']._serialized_end=516
  _globals['_MALIMALIKCPUFENCESIGNALFTRACEEVENT']._serialized_start=518
  _globals['_MALIMALIKCPUFENCESIGNALFTRACEEVENT']._serialized_end=640
  _globals['_MALIMALIKCPUFENCEWAITSTARTFTRACEEVENT']._serialized_start=642
  _globals['_MALIMALIKCPUFENCEWAITSTARTFTRACEEVENT']._serialized_end=767
  _globals['_MALIMALIKCPUFENCEWAITENDFTRACEEVENT']._serialized_start=769
  _globals['_MALIMALIKCPUFENCEWAITENDFTRACEEVENT']._serialized_end=892
  _globals['_MALIMALICSFINTERRUPTSTARTFTRACEEVENT']._serialized_start=894
  _globals['_MALIMALICSFINTERRUPTSTARTFTRACEEVENT']._serialized_end=986
  _globals['_MALIMALICSFINTERRUPTENDFTRACEEVENT']._serialized_start=988
  _globals['_MALIMALICSFINTERRUPTENDFTRACEEVENT']._serialized_end=1078
  _globals['_MALIMALIPMMCUHCTLCORESDOWNSCALENOTIFYPENDFTRACEEVENT']._serialized_start=1080
  _globals['_MALIMALIPMMCUHCTLCORESDOWNSCALENOTIFYPENDFTRACEEVENT']._serialized_end=1188
  _globals['_MALIMALIPMMCUHCTLCORESNOTIFYPENDFTRACEEVENT']._serialized_start=1190
  _globals['_MALIMALIPMMCUHCTLCORESNOTIFYPENDFTRACEEVENT']._serialized_end=1289
  _globals['_MALIMALIPMMCUHCTLCOREINACTIVEPENDFTRACEEVENT']._serialized_start=1291
  _globals['_MALIMALIPMMCUHCTLCOREINACTIVEPENDFTRACEEVENT']._serialized_end=1391
  _globals['_MALIMALIPMMCUHCTLMCUONRECHECKFTRACEEVENT']._serialized_start=1393
  _globals['_MALIMALIPMMCUHCTLMCUONRECHECKFTRACEEVENT']._serialized_end=1489
  _globals['_MALIMALIPMMCUHCTLSHADERSCOREOFFPENDFTRACEEVENT']._serialized_start=1491
  _globals['_MALIMALIPMMCUHCTLSHADERSCOREOFFPENDFTRACEEVENT']._serialized_end=1593
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDOFFFTRACEEVENT']._serialized_start=1595
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDOFFFTRACEEVENT']._serialized_end=1693
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDONFTRACEEVENT']._serialized_start=1695
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDONFTRACEEVENT']._serialized_end=1792
  _globals['_MALIMALIPMMCUHCTLSHADERSREADYOFFFTRACEEVENT']._serialized_start=1794
  _globals['_MALIMALIPMMCUHCTLSHADERSREADYOFFFTRACEEVENT']._serialized_end=1893
  _globals['_MALIMALIPMMCUINSLEEPFTRACEEVENT']._serialized_start=1895
  _globals['_MALIMALIPMMCUINSLEEPFTRACEEVENT']._serialized_end=1982
  _globals['_MALIMALIPMMCUOFFFTRACEEVENT']._serialized_start=1984
  _globals['_MALIMALIPMMCUOFFFTRACEEVENT']._serialized_end=2067
  _globals['_MALIMALIPMMCUONFTRACEEVENT']._serialized_start=2069
  _globals['_MALIMALIPMMCUONFTRACEEVENT']._serialized_end=2151
  _globals['_MALIMALIPMMCUONCOREATTRUPDATEPENDFTRACEEVENT']._serialized_start=2153
  _globals['_MALIMALIPMMCUONCOREATTRUPDATEPENDFTRACEEVENT']._serialized_end=2253
  _globals['_MALIMALIPMMCUONGLBREINITPENDFTRACEEVENT']._serialized_start=2255
  _globals['_MALIMALIPMMCUONGLBREINITPENDFTRACEEVENT']._serialized_end=2350
  _globals['_MALIMALIPMMCUONHALTFTRACEEVENT']._serialized_start=2352
  _globals['_MALIMALIPMMCUONHALTFTRACEEVENT']._serialized_end=2438
  _globals['_MALIMALIPMMCUONHWCNTDISABLEFTRACEEVENT']._serialized_start=2440
  _globals['_MALIMALIPMMCUONHWCNTDISABLEFTRACEEVENT']._serialized_end=2534
  _globals['_MALIMALIPMMCUONHWCNTENABLEFTRACEEVENT']._serialized_start=2536
  _globals['_MALIMALIPMMCUONHWCNTENABLEFTRACEEVENT']._serialized_end=2629
  _globals['_MALIMALIPMMCUONPENDHALTFTRACEEVENT']._serialized_start=2631
  _globals['_MALIMALIPMMCUONPENDHALTFTRACEEVENT']._serialized_end=2721
  _globals['_MALIMALIPMMCUONPENDSLEEPFTRACEEVENT']._serialized_start=2723
  _globals['_MALIMALIPMMCUONPENDSLEEPFTRACEEVENT']._serialized_end=2814
  _globals['_MALIMALIPMMCUONSLEEPINITIATEFTRACEEVENT']._serialized_start=2816
  _globals['_MALIMALIPMMCUONSLEEPINITIATEFTRACEEVENT']._serialized_end=2911
  _globals['_MALIMALIPMMCUPENDOFFFTRACEEVENT']._serialized_start=2913
  _globals['_MALIMALIPMMCUPENDOFFFTRACEEVENT']._serialized_end=3000
  _globals['_MALIMALIPMMCUPENDONRELOADFTRACEEVENT']._serialized_start=3002
  _globals['_MALIMALIPMMCUPENDONRELOADFTRACEEVENT']._serialized_end=3094
  _globals['_MALIMALIPMMCUPOWERDOWNFTRACEEVENT']._serialized_start=3096
  _globals['_MALIMALIPMMCUPOWERDOWNFTRACEEVENT']._serialized_end=3185
  _globals['_MALIMALIPMMCURESETWAITFTRACEEVENT']._serialized_start=3187
  _globals['_MALIMALIPMMCURESETWAITFTRACEEVENT']._serialized_end=3276
# @@protoc_insertion_point(module_scope)
