# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/binder.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/binder.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)protos/perfetto/trace/ftrace/binder.proto\x12\x0fperfetto.protos\"\x95\x01\n\x1c\x42inderTransactionFtraceEvent\x12\x10\n\x08\x64\x65\x62ug_id\x18\x01 \x01(\x05\x12\x13\n\x0btarget_node\x18\x02 \x01(\x05\x12\x0f\n\x07to_proc\x18\x03 \x01(\x05\x12\x11\n\tto_thread\x18\x04 \x01(\x05\x12\r\n\x05reply\x18\x05 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\"8\n$BinderTransactionReceivedFtraceEvent\x12\x10\n\x08\x64\x65\x62ug_id\x18\x01 \x01(\x05\"v\n\x1c\x42inderSetPriorityFtraceEvent\x12\x0c\n\x04proc\x18\x01 \x01(\x05\x12\x0e\n\x06thread\x18\x02 \x01(\x05\x12\x10\n\x08old_prio\x18\x03 \x01(\r\x12\x10\n\x08new_prio\x18\x04 \x01(\r\x12\x14\n\x0c\x64\x65sired_prio\x18\x05 \x01(\r\"$\n\x15\x42inderLockFtraceEvent\x12\x0b\n\x03tag\x18\x01 \x01(\t\"&\n\x17\x42inderLockedFtraceEvent\x12\x0b\n\x03tag\x18\x01 \x01(\t\"&\n\x17\x42inderUnlockFtraceEvent\x12\x0b\n\x03tag\x18\x01 \x01(\t\"}\n$BinderTransactionAllocBufFtraceEvent\x12\x11\n\tdata_size\x18\x01 \x01(\x04\x12\x10\n\x08\x64\x65\x62ug_id\x18\x02 \x01(\x05\x12\x14\n\x0coffsets_size\x18\x03 \x01(\x04\x12\x1a\n\x12\x65xtra_buffers_size\x18\x04 \x01(\x04\"\'\n\x18\x42inderCommandFtraceEvent\x12\x0b\n\x03\x63md\x18\x01 \x01(\r\"&\n\x17\x42inderReturnFtraceEvent\x12\x0b\n\x03\x63md\x18\x01 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.binder_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BINDERTRANSACTIONFTRACEEVENT']._serialized_start=63
  _globals['_BINDERTRANSACTIONFTRACEEVENT']._serialized_end=212
  _globals['_BINDERTRANSACTIONRECEIVEDFTRACEEVENT']._serialized_start=214
  _globals['_BINDERTRANSACTIONRECEIVEDFTRACEEVENT']._serialized_end=270
  _globals['_BINDERSETPRIORITYFTRACEEVENT']._serialized_start=272
  _globals['_BINDERSETPRIORITYFTRACEEVENT']._serialized_end=390
  _globals['_BINDERLOCKFTRACEEVENT']._serialized_start=392
  _globals['_BINDERLOCKFTRACEEVENT']._serialized_end=428
  _globals['_BINDERLOCKEDFTRACEEVENT']._serialized_start=430
  _globals['_BINDERLOCKEDFTRACEEVENT']._serialized_end=468
  _globals['_BINDERUNLOCKFTRACEEVENT']._serialized_start=470
  _globals['_BINDERUNLOCKFTRACEEVENT']._serialized_end=508
  _globals['_BINDERTRANSACTIONALLOCBUFFTRACEEVENT']._serialized_start=510
  _globals['_BINDERTRANSACTIONALLOCBUFFTRACEEVENT']._serialized_end=635
  _globals['_BINDERCOMMANDFTRACEEVENT']._serialized_start=637
  _globals['_BINDERCOMMANDFTRACEEVENT']._serialized_end=676
  _globals['_BINDERRETURNFTRACEEVENT']._serialized_start=678
  _globals['_BINDERRETURNFTRACEEVENT']._serialized_end=716
# @@protoc_insertion_point(module_scope)
