# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/remote_clock_sync.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/remote_clock_sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace import clock_snapshot_pb2 as protos_dot_perfetto_dot_trace_dot_clock__snapshot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-protos/perfetto/trace/remote_clock_sync.proto\x12\x0fperfetto.protos\x1a*protos/perfetto/trace/clock_snapshot.proto\"\xd3\x01\n\x0fRemoteClockSync\x12\x44\n\rsynced_clocks\x18\x01 \x03(\x0b\x32-.perfetto.protos.RemoteClockSync.SyncedClocks\x1az\n\x0cSyncedClocks\x12\x35\n\rclient_clocks\x18\x02 \x01(\x0b\x32\x1e.perfetto.protos.ClockSnapshot\x12\x33\n\x0bhost_clocks\x18\x03 \x01(\x0b\x32\x1e.perfetto.protos.ClockSnapshot')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.remote_clock_sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REMOTECLOCKSYNC']._serialized_start=111
  _globals['_REMOTECLOCKSYNC']._serialized_end=322
  _globals['_REMOTECLOCKSYNC_SYNCEDCLOCKS']._serialized_start=200
  _globals['_REMOTECLOCKSYNC_SYNCEDCLOCKS']._serialized_end=322
# @@protoc_insertion_point(module_scope)
