# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/kmem.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/kmem.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'protos/perfetto/trace/ftrace/kmem.proto\x12\x0fperfetto.protos\"A\n\x1d\x41llocPagesIommuEndFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\r\n\x05order\x18\x02 \x01(\r\"B\n\x1e\x41llocPagesIommuFailFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\r\n\x05order\x18\x02 \x01(\r\"C\n\x1f\x41llocPagesIommuStartFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\r\n\x05order\x18\x02 \x01(\r\"?\n\x1b\x41llocPagesSysEndFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\r\n\x05order\x18\x02 \x01(\r\"@\n\x1c\x41llocPagesSysFailFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\r\n\x05order\x18\x02 \x01(\r\"A\n\x1d\x41llocPagesSysStartFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\r\n\x05order\x18\x02 \x01(\r\"3\n\"DmaAllocContiguousRetryFtraceEvent\x12\r\n\x05tries\x18\x01 \x01(\x05\"S\n\x18IommuMapRangeFtraceEvent\x12\x12\n\nchunk_size\x18\x01 \x01(\x04\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\n\n\x02pa\x18\x03 \x01(\x04\x12\n\n\x02va\x18\x04 \x01(\x04\"f\n\"IommuSecPtblMapRangeEndFtraceEvent\x12\x0b\n\x03len\x18\x01 \x01(\x04\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\n\n\x02pa\x18\x03 \x01(\r\x12\x0e\n\x06sec_id\x18\x04 \x01(\x05\x12\n\n\x02va\x18\x05 \x01(\x04\"h\n$IommuSecPtblMapRangeStartFtraceEvent\x12\x0b\n\x03len\x18\x01 \x01(\x04\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\n\n\x02pa\x18\x03 \x01(\r\x12\x0e\n\x06sec_id\x18\x04 \x01(\x05\x12\n\n\x02va\x18\x05 \x01(\x04\"p\n\x1cIonAllocBufferEndFtraceEvent\x12\x13\n\x0b\x63lient_name\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\x11\n\theap_name\x18\x03 \x01(\t\x12\x0b\n\x03len\x18\x04 \x01(\x04\x12\x0c\n\x04mask\x18\x05 \x01(\r\"\x80\x01\n\x1dIonAllocBufferFailFtraceEvent\x12\x13\n\x0b\x63lient_name\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\x03\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x11\n\theap_name\x18\x04 \x01(\t\x12\x0b\n\x03len\x18\x05 \x01(\x04\x12\x0c\n\x04mask\x18\x06 \x01(\r\"\x84\x01\n!IonAllocBufferFallbackFtraceEvent\x12\x13\n\x0b\x63lient_name\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\x03\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x11\n\theap_name\x18\x04 \x01(\t\x12\x0b\n\x03len\x18\x05 \x01(\x04\x12\x0c\n\x04mask\x18\x06 \x01(\r\"r\n\x1eIonAllocBufferStartFtraceEvent\x12\x13\n\x0b\x63lient_name\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\x11\n\theap_name\x18\x03 \x01(\t\x12\x0b\n\x03len\x18\x04 \x01(\x04\x12\x0c\n\x04mask\x18\x05 \x01(\r\"+\n\x1aIonCpAllocRetryFtraceEvent\x12\r\n\x05tries\x18\x01 \x01(\x05\"_\n\x1fIonCpSecureBufferEndFtraceEvent\x12\r\n\x05\x61lign\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\x04\x12\x11\n\theap_name\x18\x03 \x01(\t\x12\x0b\n\x03len\x18\x04 \x01(\x04\"a\n!IonCpSecureBufferStartFtraceEvent\x12\r\n\x05\x61lign\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\x04\x12\x11\n\theap_name\x18\x03 \x01(\t\x12\x0b\n\x03len\x18\x04 \x01(\x04\"(\n\x19IonPrefetchingFtraceEvent\x12\x0b\n\x03len\x18\x01 \x01(\x04\"[\n#IonSecureCmaAddToPoolEndFtraceEvent\x12\x13\n\x0bis_prefetch\x18\x01 \x01(\r\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\x12\n\npool_total\x18\x03 \x01(\x05\"]\n%IonSecureCmaAddToPoolStartFtraceEvent\x12\x13\n\x0bis_prefetch\x18\x01 \x01(\r\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\x12\n\npool_total\x18\x03 \x01(\x05\"b\n\"IonSecureCmaAllocateEndFtraceEvent\x12\r\n\x05\x61lign\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\x04\x12\x11\n\theap_name\x18\x03 \x01(\t\x12\x0b\n\x03len\x18\x04 \x01(\x04\"d\n$IonSecureCmaAllocateStartFtraceEvent\x12\r\n\x05\x61lign\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\x04\x12\x11\n\theap_name\x18\x03 \x01(\t\x12\x0b\n\x03len\x18\x04 \x01(\x04\"R\n$IonSecureCmaShrinkPoolEndFtraceEvent\x12\x14\n\x0c\x64rained_size\x18\x01 \x01(\x04\x12\x14\n\x0cskipped_size\x18\x02 \x01(\x04\"T\n&IonSecureCmaShrinkPoolStartFtraceEvent\x12\x14\n\x0c\x64rained_size\x18\x01 \x01(\x04\x12\x14\n\x0cskipped_size\x18\x02 \x01(\x04\"2\n\x10KfreeFtraceEvent\x12\x11\n\tcall_site\x18\x01 \x01(\x04\x12\x0b\n\x03ptr\x18\x02 \x01(\x04\"o\n\x12KmallocFtraceEvent\x12\x13\n\x0b\x62ytes_alloc\x18\x01 \x01(\x04\x12\x11\n\tbytes_req\x18\x02 \x01(\x04\x12\x11\n\tcall_site\x18\x03 \x01(\x04\x12\x11\n\tgfp_flags\x18\x04 \x01(\r\x12\x0b\n\x03ptr\x18\x05 \x01(\x04\"\x81\x01\n\x16KmallocNodeFtraceEvent\x12\x13\n\x0b\x62ytes_alloc\x18\x01 \x01(\x04\x12\x11\n\tbytes_req\x18\x02 \x01(\x04\x12\x11\n\tcall_site\x18\x03 \x01(\x04\x12\x11\n\tgfp_flags\x18\x04 \x01(\r\x12\x0c\n\x04node\x18\x05 \x01(\x05\x12\x0b\n\x03ptr\x18\x06 \x01(\x04\"v\n\x19KmemCacheAllocFtraceEvent\x12\x13\n\x0b\x62ytes_alloc\x18\x01 \x01(\x04\x12\x11\n\tbytes_req\x18\x02 \x01(\x04\x12\x11\n\tcall_site\x18\x03 \x01(\x04\x12\x11\n\tgfp_flags\x18\x04 \x01(\r\x12\x0b\n\x03ptr\x18\x05 \x01(\x04\"\x88\x01\n\x1dKmemCacheAllocNodeFtraceEvent\x12\x13\n\x0b\x62ytes_alloc\x18\x01 \x01(\x04\x12\x11\n\tbytes_req\x18\x02 \x01(\x04\x12\x11\n\tcall_site\x18\x03 \x01(\x04\x12\x11\n\tgfp_flags\x18\x04 \x01(\r\x12\x0c\n\x04node\x18\x05 \x01(\x05\x12\x0b\n\x03ptr\x18\x06 \x01(\x04\":\n\x18KmemCacheFreeFtraceEvent\x12\x11\n\tcall_site\x18\x01 \x01(\x04\x12\x0b\n\x03ptr\x18\x02 \x01(\x04\"*\n\x1aMigratePagesEndFtraceEvent\x12\x0c\n\x04mode\x18\x01 \x01(\x05\",\n\x1cMigratePagesStartFtraceEvent\x12\x0c\n\x04mode\x18\x01 \x01(\x05\"(\n\x17MigrateRetryFtraceEvent\x12\r\n\x05tries\x18\x01 \x01(\x05\"j\n\x16MmPageAllocFtraceEvent\x12\x11\n\tgfp_flags\x18\x01 \x01(\r\x12\x13\n\x0bmigratetype\x18\x02 \x01(\x05\x12\r\n\x05order\x18\x03 \x01(\r\x12\x0c\n\x04page\x18\x04 \x01(\x04\x12\x0b\n\x03pfn\x18\x05 \x01(\x04\"\xba\x01\n\x1dMmPageAllocExtfragFtraceEvent\x12\x19\n\x11\x61lloc_migratetype\x18\x01 \x01(\x05\x12\x13\n\x0b\x61lloc_order\x18\x02 \x01(\x05\x12\x1c\n\x14\x66\x61llback_migratetype\x18\x03 \x01(\x05\x12\x16\n\x0e\x66\x61llback_order\x18\x04 \x01(\x05\x12\x0c\n\x04page\x18\x05 \x01(\x04\x12\x18\n\x10\x63hange_ownership\x18\x06 \x01(\x05\x12\x0b\n\x03pfn\x18\x07 \x01(\x04\"a\n MmPageAllocZoneLockedFtraceEvent\x12\x13\n\x0bmigratetype\x18\x01 \x01(\x05\x12\r\n\x05order\x18\x02 \x01(\r\x12\x0c\n\x04page\x18\x03 \x01(\x04\x12\x0b\n\x03pfn\x18\x04 \x01(\x04\"A\n\x15MmPageFreeFtraceEvent\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0c\n\x04page\x18\x02 \x01(\x04\x12\x0b\n\x03pfn\x18\x03 \x01(\x04\"G\n\x1cMmPageFreeBatchedFtraceEvent\x12\x0c\n\x04\x63old\x18\x01 \x01(\x05\x12\x0c\n\x04page\x18\x02 \x01(\x04\x12\x0b\n\x03pfn\x18\x03 \x01(\x04\"[\n\x1aMmPagePcpuDrainFtraceEvent\x12\x13\n\x0bmigratetype\x18\x01 \x01(\x05\x12\r\n\x05order\x18\x02 \x01(\r\x12\x0c\n\x04page\x18\x03 \x01(\x04\x12\x0b\n\x03pfn\x18\x04 \x01(\x04\"O\n\x12RssStatFtraceEvent\x12\x0e\n\x06member\x18\x01 \x01(\x05\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x0c\n\x04\x63urr\x18\x03 \x01(\r\x12\r\n\x05mm_id\x18\x04 \x01(\r\"S\n\x18IonHeapShrinkFtraceEvent\x12\x11\n\theap_name\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\x17\n\x0ftotal_allocated\x18\x03 \x01(\x03\"Q\n\x16IonHeapGrowFtraceEvent\x12\x11\n\theap_name\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x02 \x01(\x04\x12\x17\n\x0ftotal_allocated\x18\x03 \x01(\x03\"7\n\x1aIonBufferCreateFtraceEvent\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x04\x12\x0b\n\x03len\x18\x02 \x01(\x04\"8\n\x1bIonBufferDestroyFtraceEvent\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x04\x12\x0b\n\x03len\x18\x02 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.kmem_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALLOCPAGESIOMMUENDFTRACEEVENT']._serialized_start=60
  _globals['_ALLOCPAGESIOMMUENDFTRACEEVENT']._serialized_end=125
  _globals['_ALLOCPAGESIOMMUFAILFTRACEEVENT']._serialized_start=127
  _globals['_ALLOCPAGESIOMMUFAILFTRACEEVENT']._serialized_end=193
  _globals['_ALLOCPAGESIOMMUSTARTFTRACEEVENT']._serialized_start=195
  _globals['_ALLOCPAGESIOMMUSTARTFTRACEEVENT']._serialized_end=262
  _globals['_ALLOCPAGESSYSENDFTRACEEVENT']._serialized_start=264
  _globals['_ALLOCPAGESSYSENDFTRACEEVENT']._serialized_end=327
  _globals['_ALLOCPAGESSYSFAILFTRACEEVENT']._serialized_start=329
  _globals['_ALLOCPAGESSYSFAILFTRACEEVENT']._serialized_end=393
  _globals['_ALLOCPAGESSYSSTARTFTRACEEVENT']._serialized_start=395
  _globals['_ALLOCPAGESSYSSTARTFTRACEEVENT']._serialized_end=460
  _globals['_DMAALLOCCONTIGUOUSRETRYFTRACEEVENT']._serialized_start=462
  _globals['_DMAALLOCCONTIGUOUSRETRYFTRACEEVENT']._serialized_end=513
  _globals['_IOMMUMAPRANGEFTRACEEVENT']._serialized_start=515
  _globals['_IOMMUMAPRANGEFTRACEEVENT']._serialized_end=598
  _globals['_IOMMUSECPTBLMAPRANGEENDFTRACEEVENT']._serialized_start=600
  _globals['_IOMMUSECPTBLMAPRANGEENDFTRACEEVENT']._serialized_end=702
  _globals['_IOMMUSECPTBLMAPRANGESTARTFTRACEEVENT']._serialized_start=704
  _globals['_IOMMUSECPTBLMAPRANGESTARTFTRACEEVENT']._serialized_end=808
  _globals['_IONALLOCBUFFERENDFTRACEEVENT']._serialized_start=810
  _globals['_IONALLOCBUFFERENDFTRACEEVENT']._serialized_end=922
  _globals['_IONALLOCBUFFERFAILFTRACEEVENT']._serialized_start=925
  _globals['_IONALLOCBUFFERFAILFTRACEEVENT']._serialized_end=1053
  _globals['_IONALLOCBUFFERFALLBACKFTRACEEVENT']._serialized_start=1056
  _globals['_IONALLOCBUFFERFALLBACKFTRACEEVENT']._serialized_end=1188
  _globals['_IONALLOCBUFFERSTARTFTRACEEVENT']._serialized_start=1190
  _globals['_IONALLOCBUFFERSTARTFTRACEEVENT']._serialized_end=1304
  _globals['_IONCPALLOCRETRYFTRACEEVENT']._serialized_start=1306
  _globals['_IONCPALLOCRETRYFTRACEEVENT']._serialized_end=1349
  _globals['_IONCPSECUREBUFFERENDFTRACEEVENT']._serialized_start=1351
  _globals['_IONCPSECUREBUFFERENDFTRACEEVENT']._serialized_end=1446
  _globals['_IONCPSECUREBUFFERSTARTFTRACEEVENT']._serialized_start=1448
  _globals['_IONCPSECUREBUFFERSTARTFTRACEEVENT']._serialized_end=1545
  _globals['_IONPREFETCHINGFTRACEEVENT']._serialized_start=1547
  _globals['_IONPREFETCHINGFTRACEEVENT']._serialized_end=1587
  _globals['_IONSECURECMAADDTOPOOLENDFTRACEEVENT']._serialized_start=1589
  _globals['_IONSECURECMAADDTOPOOLENDFTRACEEVENT']._serialized_end=1680
  _globals['_IONSECURECMAADDTOPOOLSTARTFTRACEEVENT']._serialized_start=1682
  _globals['_IONSECURECMAADDTOPOOLSTARTFTRACEEVENT']._serialized_end=1775
  _globals['_IONSECURECMAALLOCATEENDFTRACEEVENT']._serialized_start=1777
  _globals['_IONSECURECMAALLOCATEENDFTRACEEVENT']._serialized_end=1875
  _globals['_IONSECURECMAALLOCATESTARTFTRACEEVENT']._serialized_start=1877
  _globals['_IONSECURECMAALLOCATESTARTFTRACEEVENT']._serialized_end=1977
  _globals['_IONSECURECMASHRINKPOOLENDFTRACEEVENT']._serialized_start=1979
  _globals['_IONSECURECMASHRINKPOOLENDFTRACEEVENT']._serialized_end=2061
  _globals['_IONSECURECMASHRINKPOOLSTARTFTRACEEVENT']._serialized_start=2063
  _globals['_IONSECURECMASHRINKPOOLSTARTFTRACEEVENT']._serialized_end=2147
  _globals['_KFREEFTRACEEVENT']._serialized_start=2149
  _globals['_KFREEFTRACEEVENT']._serialized_end=2199
  _globals['_KMALLOCFTRACEEVENT']._serialized_start=2201
  _globals['_KMALLOCFTRACEEVENT']._serialized_end=2312
  _globals['_KMALLOCNODEFTRACEEVENT']._serialized_start=2315
  _globals['_KMALLOCNODEFTRACEEVENT']._serialized_end=2444
  _globals['_KMEMCACHEALLOCFTRACEEVENT']._serialized_start=2446
  _globals['_KMEMCACHEALLOCFTRACEEVENT']._serialized_end=2564
  _globals['_KMEMCACHEALLOCNODEFTRACEEVENT']._serialized_start=2567
  _globals['_KMEMCACHEALLOCNODEFTRACEEVENT']._serialized_end=2703
  _globals['_KMEMCACHEFREEFTRACEEVENT']._serialized_start=2705
  _globals['_KMEMCACHEFREEFTRACEEVENT']._serialized_end=2763
  _globals['_MIGRATEPAGESENDFTRACEEVENT']._serialized_start=2765
  _globals['_MIGRATEPAGESENDFTRACEEVENT']._serialized_end=2807
  _globals['_MIGRATEPAGESSTARTFTRACEEVENT']._serialized_start=2809
  _globals['_MIGRATEPAGESSTARTFTRACEEVENT']._serialized_end=2853
  _globals['_MIGRATERETRYFTRACEEVENT']._serialized_start=2855
  _globals['_MIGRATERETRYFTRACEEVENT']._serialized_end=2895
  _globals['_MMPAGEALLOCFTRACEEVENT']._serialized_start=2897
  _globals['_MMPAGEALLOCFTRACEEVENT']._serialized_end=3003
  _globals['_MMPAGEALLOCEXTFRAGFTRACEEVENT']._serialized_start=3006
  _globals['_MMPAGEALLOCEXTFRAGFTRACEEVENT']._serialized_end=3192
  _globals['_MMPAGEALLOCZONELOCKEDFTRACEEVENT']._serialized_start=3194
  _globals['_MMPAGEALLOCZONELOCKEDFTRACEEVENT']._serialized_end=3291
  _globals['_MMPAGEFREEFTRACEEVENT']._serialized_start=3293
  _globals['_MMPAGEFREEFTRACEEVENT']._serialized_end=3358
  _globals['_MMPAGEFREEBATCHEDFTRACEEVENT']._serialized_start=3360
  _globals['_MMPAGEFREEBATCHEDFTRACEEVENT']._serialized_end=3431
  _globals['_MMPAGEPCPUDRAINFTRACEEVENT']._serialized_start=3433
  _globals['_MMPAGEPCPUDRAINFTRACEEVENT']._serialized_end=3524
  _globals['_RSSSTATFTRACEEVENT']._serialized_start=3526
  _globals['_RSSSTATFTRACEEVENT']._serialized_end=3605
  _globals['_IONHEAPSHRINKFTRACEEVENT']._serialized_start=3607
  _globals['_IONHEAPSHRINKFTRACEEVENT']._serialized_end=3690
  _globals['_IONHEAPGROWFTRACEEVENT']._serialized_start=3692
  _globals['_IONHEAPGROWFTRACEEVENT']._serialized_end=3773
  _globals['_IONBUFFERCREATEFTRACEEVENT']._serialized_start=3775
  _globals['_IONBUFFERCREATEFTRACEEVENT']._serialized_end=3830
  _globals['_IONBUFFERDESTROYFTRACEEVENT']._serialized_start=3832
  _globals['_IONBUFFERDESTROYFTRACEEVENT']._serialized_end=3888
# @@protoc_insertion_point(module_scope)
