# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/track_event/chrome_thread_descriptor.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/track_event/chrome_thread_descriptor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@protos/perfetto/trace/track_event/chrome_thread_descriptor.proto\x12\x0fperfetto.protos\"\xec\t\n\x16\x43hromeThreadDescriptor\x12G\n\x0bthread_type\x18\x01 \x01(\x0e\x32\x32.perfetto.protos.ChromeThreadDescriptor.ThreadType\x12\x19\n\x11legacy_sort_index\x18\x02 \x01(\x05\"\xed\x08\n\nThreadType\x12\x16\n\x12THREAD_UNSPECIFIED\x10\x00\x12\x0f\n\x0bTHREAD_MAIN\x10\x01\x12\r\n\tTHREAD_IO\x10\x02\x12\x19\n\x15THREAD_POOL_BG_WORKER\x10\x03\x12\x19\n\x15THREAD_POOL_FG_WORKER\x10\x04\x12\x1b\n\x17THREAD_POOL_FG_BLOCKING\x10\x05\x12\x1b\n\x17THREAD_POOL_BG_BLOCKING\x10\x06\x12\x17\n\x13THREAD_POOL_SERVICE\x10\x07\x12\x15\n\x11THREAD_COMPOSITOR\x10\x08\x12\x19\n\x15THREAD_VIZ_COMPOSITOR\x10\t\x12\x1c\n\x18THREAD_COMPOSITOR_WORKER\x10\n\x12\x19\n\x15THREAD_SERVICE_WORKER\x10\x0b\x12\x1a\n\x16THREAD_NETWORK_SERVICE\x10\x0c\x12\x13\n\x0fTHREAD_CHILD_IO\x10\r\x12\x15\n\x11THREAD_BROWSER_IO\x10\x0e\x12\x17\n\x13THREAD_BROWSER_MAIN\x10\x0f\x12\x18\n\x14THREAD_RENDERER_MAIN\x10\x10\x12\x17\n\x13THREAD_UTILITY_MAIN\x10\x11\x12\x13\n\x0fTHREAD_GPU_MAIN\x10\x12\x12\x1a\n\x16THREAD_CACHE_BLOCKFILE\x10\x13\x12\x10\n\x0cTHREAD_MEDIA\x10\x14\x12\x1d\n\x19THREAD_AUDIO_OUTPUTDEVICE\x10\x15\x12\x1c\n\x18THREAD_AUDIO_INPUTDEVICE\x10\x16\x12\x15\n\x11THREAD_GPU_MEMORY\x10\x17\x12\x14\n\x10THREAD_GPU_VSYNC\x10\x18\x12\x1b\n\x17THREAD_DXA_VIDEODECODER\x10\x19\x12\x1b\n\x17THREAD_BROWSER_WATCHDOG\x10\x1a\x12\x19\n\x15THREAD_WEBRTC_NETWORK\x10\x1b\x12\x17\n\x13THREAD_WINDOW_OWNER\x10\x1c\x12\x1b\n\x17THREAD_WEBRTC_SIGNALING\x10\x1d\x12\x18\n\x14THREAD_WEBRTC_WORKER\x10\x1e\x12\x15\n\x11THREAD_PPAPI_MAIN\x10\x1f\x12\x17\n\x13THREAD_GPU_WATCHDOG\x10 \x12\x12\n\x0eTHREAD_SWAPPER\x10!\x12\x1a\n\x16THREAD_GAMEPAD_POLLING\x10\"\x12\x14\n\x10THREAD_WEBCRYPTO\x10#\x12\x13\n\x0fTHREAD_DATABASE\x10$\x12\x18\n\x14THREAD_PROXYRESOLVER\x10%\x12\x16\n\x12THREAD_DEVTOOLSADB\x10&\x12\x1f\n\x1bTHREAD_NETWORKCONFIGWATCHER\x10\'\x12\x18\n\x14THREAD_WASAPI_RENDER\x10(\x12\x1e\n\x1aTHREAD_LOADER_LOCK_SAMPLER\x10)\x12\x17\n\x13THREAD_MEMORY_INFRA\x10\x32\x12\x1c\n\x18THREAD_SAMPLING_PROFILER\x10\x33')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.track_event.chrome_thread_descriptor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMETHREADDESCRIPTOR']._serialized_start=86
  _globals['_CHROMETHREADDESCRIPTOR']._serialized_end=1346
  _globals['_CHROMETHREADDESCRIPTOR_THREADTYPE']._serialized_start=213
  _globals['_CHROMETHREADDESCRIPTOR_THREADTYPE']._serialized_end=1346
# @@protoc_insertion_point(module_scope)
